@@ -26,10 +26,23 @@ please send it to me, with a reference to back up your claim. Thanks.
 Philippe "BooK" Bruhat, inspired by David Landgren's presentation of
 L<Acme::DonMartin>.
 
-Introduced in Acme-MetaSyntactic version 0.32, published on July 25, 2005.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-07-25
+
+Introduced in Acme-MetaSyntactic version 0.32.
+
+=back
 
 =head1 SEE ALSO
 
