@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pokemon;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -27,7 +27,7 @@ Acme::MetaSyntactic::pokemon - The Pokmon theme
 
 =head1 DESCRIPTION
 
-List of the 648 Pokmon characters that are officially known to exist
+List of the 649 Pokmon characters that are officially known to exist
 in the franchise.
 
 This list is based on the following wikipedia article:
@@ -47,6 +47,13 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2012-07-23 - v1.002
+
+Updated with a new Pokmon
+in Acme-MetaSyntactic-Themes version 1.011.
+
+=item *
+
 2012-05-14 - v1.001
 
 Updated with typographical corrections by Abigail
@@ -759,3 +766,4 @@ Landorus
 Kyurem
 Keldeo
 Meloetta
+Genesect
